#!/usr/bin/env Rscript

source("colors.R")

library(lme4)

unlogit <- function(x) 1/(1+exp(-x))
errbar <- function(x0, x1, y, text="ns") {
	lines(x=c(x0, x1), y=c(y,y), col="gray", lwd=6)
	text(0.5*(x0+x1), y, text, cex=1.2)
}

errdelta <- 0.05


ps6 <- read.table("../data/black-red.txt", header=TRUE)
ps6$PS6 <- ifelse(ps6$Color=="red", 1, 0)
ps6$Genotype <- relevel(ps6$Genotype, ref="MARCM-T3")
ps6$Larva <- factor(ps6$Larva)
ps6$Series <- factor(ps6$Series)


mod.ps6 <- glmer(PS6 ~ 0 + Genotype + (1|Larva/Series), data=ps6, family=binomial())
ps6.eff <- coef(summary(mod.ps6))[,"Estimate"]
ps6.CI <- confint(mod.ps6, method="Wald")[-(1:2),] # Other methods are much longer to compute

names(ps6.eff) <- levels(ps6$Genotype)
rownames(ps6.CI) <- levels(ps6$Genotype)

ps6.cols <- c('MARCM-T3'=control.col, 'MARCM-FAS'=fasn.col, 'MARCM-PTEN-512'=pten.col, 'MARCM-T3-Rheb'=rheb.col, 'TOR2L1'=tor2L1.col, 'TORDeltaP'=torDp.col, 'TOR2L19'=tor2L19.col)

pdf("Fig2M.pdf", width=5, height=3)
par(lwd=2, mar=c(2.5,4,1,1))

xx <- barplot(unlogit(ps6.eff), col=ps6.cols[rownames(ps6.CI)], ylim=c(0, 1.15), ylab="", xlab="", main="", names.arg="")
mtext(expression("PS6"^"+"*" clone frequency"), 2, line=2.5)
axis(1, at=xx, c("Co",expression("FASN"^"-"), expression("PTEN"^"-"), expression("Rheb"^"+"), expression("TOR"^"2L1"), expression("TOR"^{Delta*"P"}), expression("TOR"^"2L19")), tick=FALSE, line=FALSE, mgp=c(0, 0.4, 0))
arrows(x0=xx, y0=unlogit(ps6.CI[,1]), y1=unlogit(ps6.CI[,2]), length=0.1, code=3, angle=90)

# P-values can be retrieved from TabS2

errbar(xx[1], xx[2], 1.03-2*errdelta, "ns")
errbar(xx[1], xx[3], 1.03-1*errdelta, "ns")
errbar(xx[1], xx[4], 1.03, "***")

# P-values for TOR are not displayed, as the difference is huge

dev.off()
