#!/usr/bin/env Rscript

source("colors.R")

errbar <- function(x0, x1, y, text="ns") {
	lines(x=c(x0, x1), y=c(y,y), col="gray", lwd=6)
	text(0.5*(x0+x1), y, text, cex=1.2)
}

ccol <- c(control.col, pten.col, rheb.col) #Co, PTEN, Rheb

allbarplot <- function(data, phen, ylim=NULL, showdata=TRUE, ylab="", factor.levels=c("W", "Ri37", "Rheb"), ...) {
    newd <- data.frame(Genotype=data$Genotype, Sugar=data$Sugar, Phen=data[,phen])
    newd$Genotype <- factor(newd$Genotype, levels=factor.levels)
    newd$All <- interaction(newd$Genotype, newd$Sugar)
        
    spl <-  split(newd$Phen, list(newd$Genotype, newd$Sugar))
    
    at <- c(1:3, 5:7)
    if (is.null(ylim)) ylim <- c(0, 1.05*max(newd$Phen))
    boxplot(spl, at=at, col=ccol, ylim=ylim, range=0, xaxt="n",  ylab="", medlty="blank", ...) #medcol="lightgray",
    mtext(ylab, 2, line=2.5)
    points(at, sapply(spl, mean), pch=5)
    axis(1, at=c(2, 6), c("0%","20%"))
}


pupweight <- read.table("../data/pupal-weight.txt", header=TRUE)
# pupal weight in mg
pupweight$Mass <- c(0, diff(pupweight$CumulMass))/10
# The first line of each series is useless (the 0 measure on the scale)
pupweight <- pupweight[pupweight$Mass > 0,]
pupweight$Genotype <- relevel(pupweight$Genotype, "white")  # white are the control
pupweight$Sugar <- relevel(pupweight$Sugar, "0%")           # 0% are the control
pupweight$Forgotten <- relevel(pupweight$Forgotten, "OK")   

TAGProt <- read.table("../data/TAGProt.txt", header=TRUE)
Sugars <- read.table("../data/Sugars.txt", header=TRUE)



TAGProt$TAGmpup <- TAGProt$TAGM/TAGProt$PupWeight
TAGProt$Protmpup <- TAGProt$ProtM/TAGProt$PupWeight

Sugars$Threampup <- Sugars$ThreaM/Sugars$PupWeight
Sugars$Glycmpup <- Sugars$GlycM/Sugars$PupWeight

labs <- LETTERS


# P-values can be retrieved from TabS3

pdf("Fig3.pdf", width=6, height=7)
layout(rbind(1:2, 3:4, 5:6))
par(lwd=1.5, mar=c(2,4,3,1), xpd=TRUE)

allbarplot(pupweight[pupweight$Sex=="male",], "Mass", ylab="Pupal Mass (mg)", ylim=c(0, 2), factor.levels=c("white", "PTEN","Rheb"))
errbar(1, 2, 0, "ns")
errbar(5, 6, 0, "***")
errbar(1, 3, 0.12, "*")
errbar(5, 7, 0.12, "***")

title("Males", line=-1.5)
mtext(labs[1], 3, adj=-0.2, cex=1.4)
legend("topright", inset=c(0, -0.2), pch=22, pt.bg=ccol, pt.cex=2, legend=c("Co","PTEN-Ri", expression("Rheb"^"++")), ncol=3)

allbarplot(pupweight[pupweight$Sex=="female",], "Mass", ylab="Pupal Mass (mg)", ylim=c(0, 2), factor.levels=c("white", "PTEN","Rheb"))
errbar(1, 2, 0, "ns")
errbar(5, 6, 0, "***")
errbar(1, 3, 0.12, "ns")
errbar(5, 7, 0.12, "***")

title("Females", line=-1.5, adj=0.6)
mtext(labs[2], 3, adj=-0.2, cex=1.4)

par(mar=c(2,4,1,1))

allbarplot(TAGProt, "Protmpup", ylab=expression("Protein "*mu*"g / Pupa "*mu*"g"))
errbar(1, 2, 0, "ns")
errbar(5, 6, 0, "***")
errbar(1, 3, 5, "ns")
errbar(5, 7, 5, "ns")

mtext(labs[3], 3, adj=-0.2, cex=1.4)

allbarplot(TAGProt, "TAGmpup", ylab=expression("TAG "*mu*"g / Pupa "*mu*"g"))
errbar(1, 2, 0, "ns")
errbar(5, 6, 0, "***")
errbar(1, 3, 7, "ns")
errbar(5, 7, 7, "ns")

mtext(labs[4], 3, adj=-0.2, cex=1.4)



allbarplot(Sugars, "Glycmpup", ylab=expression("Glycogen "*mu*"g / Pupa mg"))
errbar(1, 2, 0, "*")
errbar(5, 6, 0, "**")
errbar(1, 3, 0.4, "***")
errbar(5, 7, 0.4, "***")

mtext(labs[5], 3, adj=-0.2, cex=1.4)


allbarplot(Sugars, "Threampup", ylab=expression("Trehalose "*mu*"g / Pupa mg"))
errbar(1, 2, 0, "***")
errbar(5, 6, 0, "***")
errbar(1, 3, 0.6, "***")
errbar(5, 7, 0.6, "***")

mtext(labs[6], 3, adj=-0.2, cex=1.4)


dev.off()
