#!/usr/bin/env Rscript


errbar <- function(x0, x1, y, text="ns") {
	lines(x=c(x0, x1), y=c(y,y), col="gray", lwd=6)
	text(0.5*(x0+x1), y, text, cex=1)
}
errdelta <- 0.1

clones <- read.table("../data/clones.txt", header=TRUE)

clones$logSize <- log(clones$Size)
clones$GenotypeC2 <- factor(ifelse(clones$GenotypeC=="WT", "WT", "Expr"))
clones$Manip <- interaction(clones$GenotypeL, clones$Sugar, clones$GenotypeC2)
clones$Manip <- droplevels(clones$Manip)




singlegen <- c("T3", "PFK1-Ri", "PK-Ri", "LDH-Ri", "PDH-Ri", 
			"PTEN", "PTEN-PFK1-Ri", "PTEN-PK-Ri", "PTEN-LDH-Ri", "PTEN-PDH-Ri",
			"RHEB", "RHEB-PFK1-Ri", "RHEB-PK-Ri", "RHEB-LDH-Ri", "RHEB-PDH-Ri")

genlist <- lapply(singlegen, function(gen) {
    wtref <- clones[clones$GenotypeL==gen & clones$GenotypeC=="WT" & clones$Sugar=="0%","logSize"]
    genref <- clones[clones$GenotypeL==gen & clones$GenotypeC!="WT"& clones$Sugar=="0%","logSize"]
    genref - mean(wtref) })

names(genlist) <- singlegen

xx <- c(1:5, 7:11, 13:17)
col <- c("darkolivegreen3", "cyan", "orange", "purple", "darkred")

pdf("Fig5M.pdf", width=7, height=4.5)
par(lwd=2, mar=c(5, 4, 1, 1))


boxplot(genlist,  at=xx, xaxt="n", outline=FALSE, ylim=range(unlist(genlist)), ylab="log area relative to Co", medcol="white", col=col)
abline(h=0, col="gray", lty=3)
points(xx, sapply(genlist, mean), col="black", pch=5)
axis(1, at=xx, labels=rep(c("", "PFK1i","PKi","LDHi","PDHi"), 3), las=2, mgp=c(0, 0.7, 0)) 
axis(1, at=c(3,9,15), labels=c("Co",expression("PTEN"^"-"), expression("Rheb"^"+")), tick=FALSE, mgp=c(0, 3.5, 0))

# P-values can be retrieved from TabS1 (part C)

errbar(1, 2, 1, "ns")
errbar(1, 3, 1+errdelta, "*")
errbar(1, 4, 1+2*errdelta, "ns")
errbar(1, 5, 1+3*errdelta, "ns")

errbar(7,8,-0.7,"*")
errbar(7,9,-0.7+errdelta,"***")
errbar(7,10,-0.7+2*errdelta,"***")
errbar(7,11,-0.7+3*errdelta,"***")

errbar(13,14,-0.7,"ns")
errbar(13,15,-0.7+errdelta,"ns")
errbar(13,16,-0.7+2*errdelta,"ns")
errbar(13,17,-0.7+3*errdelta,"ns")

arrows(x0=c(1, 7, 13)-0.5, x1=c(5, 11, 17)+0.5, y0=-1.7, angle=90, code=3, length=0., xpd=NA)

dev.off()
