#!/usr/bin/env Rscript

source("colors.R")

col <- c(control.col, fasn.col, darken(control.col, 1.2), darken(fasn.col, 1.2))
errdelta <- 0.05

errbar <- function(x0, x1, y, text="ns") {
	lines(x=c(x0, x1), y=c(y,y), col="gray", lwd=6)
	text(0.5*(x0+x1), y, text, cex=1.2)
}

pupweight2 <- read.table("../data/pupal-weight2.txt", header=TRUE)
# pupal weight in mg
pupweight2$Mass <- c(0, diff(pupweight2$CumulMass))/10
# The first line of each series is useless (the 0 measure on the scale)
pupweight2 <- pupweight2[pupweight2$Mass > 0,]
pupweight2$Genotype <- relevel(pupweight2$Genotype, "white")  # white are the control
pupweight2$Sugar <- relevel(pupweight2$Sugar, "0%")           # 0% are the control

ssp2 <- split(pupweight2$Mass, list(pupweight2$Genotype, pupweight2$Sugar, pupweight2$Sex))


pdf("Fig6B.pdf", width=3.5, height=4)
par(mar=c(3.5, 3.5, 1, 1))
boxplot(ssp2, at=c(1:4, 6:9), xlim=c(0, 10), ylim=c(0, 1.8), main="", range=0, xaxt="n", col=col, medcol="gray", ylab="")
mtext("Pupal mass (mg)", 2, line=2.2)
points(c(1:4, 6:9), sapply(ssp2, mean), pch=5)
text(c(1:4, 6:9), y=sapply(ssp2, max), labels=as.character(sapply(ssp2, length)), pos=3, cex=0.7, col="darkgray")

axis(1, at=c(1.5, 3.5, 6.5, 8.5), labels=c("0%","10%", "0%", "10%"), line=0, mgp=c(1, 0.5, 1))
axis(1, at=c(2.5, 7.5), labels=c("Females","Males"), tick=FALSE, line=0.5)
mtext("Sucrose:", 1, adj=-0.2, line=0.5)

legend("topright", legend=c("             ", ""), pch=22, pt.bg=col[1:2], bty="n", pt.cex=1.5)
legend("topright", legend=c("Co","FASN"), pch=22, pt.bg=col[3:4], bty="n", pt.cex=1.5)


# P-values can be retrieved from TabS4

errbar(1, 3, 0.1, "***")
errbar(6, 8, 0.1, "**")
errbar(2, 4, 0.1+errdelta, "***")
errbar(7, 9, 0.1+errdelta, "**")
errbar(1, 2, 0.1+2*errdelta, "***")
errbar(3, 4, 0.1+2*errdelta, "***")
errbar(6, 7, 0.1+2*errdelta, "***")
errbar(8, 9,  0.1+2*errdelta, "***")

dev.off()
