#!/usr/bin/env Rscript

errbar <- function(x0, x1, y, text="ns") {
	lines(x=c(x0, x1), y=c(y,y), col="gray", lwd=6)
	text(0.5*(x0+x1), y, text, cex=1.2)
}
errdelta <- 0.2

clones <- read.table("../data/clones.txt", header=TRUE)

clones$logSize <- log(clones$Size)
clones$GenotypeC2 <- factor(ifelse(clones$GenotypeC=="WT", "WT", "Expr"))
clones$Manip <- interaction(clones$GenotypeL, clones$Sugar, clones$GenotypeC2)
clones$Manip <- droplevels(clones$Manip)

gensugar <- c("FASN","RHEB","FASN-RHEB","PTEN","FASN-PTEN","PTEN-RHEB","FASN-PTEN-RHEB","T3", "PTEN-Ri", "FASN-PTEN-Ri")
sugarcol <- c('0%'="deepskyblue4", '20%'="firebrick")

wtlist.gen0 <- lapply(gensugar, function(gen) {wtref <- clones[clones$GenotypeL==gen & clones$GenotypeC=="WT" & clones$Sugar=="0%","logSize"]; wtref - mean(wtref) })
wtlist.gen20 <- lapply(gensugar, function(gen) {wtref <- clones[clones$GenotypeL==gen & clones$GenotypeC=="WT" & clones$Sugar=="20%","logSize"]; wtref - mean(wtref) })

genlist.gen0 <- lapply(gensugar, function(gen) {
    wtref <- clones[clones$GenotypeL==gen & clones$GenotypeC=="WT" & clones$Sugar=="0%","logSize"]
    genref <- clones[clones$GenotypeL==gen & clones$GenotypeC!="WT"& clones$Sugar=="0%","logSize"]
    genref - mean(wtref) })
genlist.gen20 <- lapply(gensugar, function(gen) {
    wtref <- clones[clones$GenotypeL==gen & clones$GenotypeC=="WT" & clones$Sugar=="20%","logSize"]
    genref <- clones[clones$GenotypeL==gen & clones$GenotypeC!="WT"& clones$Sugar=="20%","logSize"]
    genref - mean(wtref) })
    
# names(wtlist.gen0) <- names(wtlist.gen20) <- names(genlist.gen0) <- names(genlist.gen0) <- gensugar


pdf("Fig7M.pdf", width=6, height=4)
par(lwd=2, mar=c(7, 4, 1, 1))

boxplot(genlist.gen0, at=seq(1, by=3, length.out=length(genlist.gen0)), border=sugarcol['0%'], boxwex=0.8, outline=FALSE, medcol="transparent", xaxt="n", ylim=c(-2, 2.6), ylab="", xlim=c(1, 29))
mtext("log area relative to Co", 2, line=2.2)
points(seq(1, by=3, length.out=length(genlist.gen0)), sapply(genlist.gen0, mean), col=sugarcol['0%'], pch=5)

boxplot(genlist.gen20, at=seq(2, by=3, length.out=length(genlist.gen20)), border=sugarcol['20%'], boxwex=0.8, outline=FALSE, medcol="transparent", add=TRUE, xaxt="n", yaxt="n")
points(seq(2, by=3, length.out=length(genlist.gen20)), sapply(genlist.gen20, mean), col=sugarcol['20%'], pch=5)

abline(h=0, lty=3, col="gray")

# axis(1, at=seq(1.5, by=3, length.out=length(gensugar)), labels=FALSE)
text(seq(1.5, by=3, length.out=length(gensugar))+c(rep(0.8,7),rep(0,3)), par("usr")[3] - 0.2, labels = c(expression("FASN"^"-"), expression("Rheb"^"+"), expression("FASN"^"-"*";Rheb"^"+"), expression("PTEN"^"-"), expression("FASN"^"-"*",PTEN"^"-"), expression("PTEN"^"-"*";Rheb"^"+"), expression("FASN"^"-"*",PTEN"^"-"*";Rheb"^"+"), "Co", "PTEN-Ri", expression("FASN"^"-"*";PTEN-Ri")), srt=45, pos = 2, xpd = TRUE)
legend("topright", pch=0, col=sugarcol, legend=names(sugarcol))

# P-values can be retrieved from TabS1 (part B)

errbar(1,2,-1.9, "***")
errbar(4,5,-1.9, "ns")
errbar(7,8,-1.9, "***")
errbar(10,11,-1.9, "***")
errbar(13,14,-1.9, "***")
errbar(16,17,-1.9, "***")
errbar(19,20,-1.9, "***")
errbar(22,23,-1.9, "ns")

errbar(1,13,2.6,"***")
errbar(16,19,2.6,"***")
errbar(1,7,2.6-errdelta,"***")
errbar(10,13,2.6-errdelta, "***")
errbar(4,7,2.6-2*errdelta,"ns")

errbar(22,28,-1.9+3*errdelta,"***")
errbar(10,25,-1.9+1*errdelta,"***")
errbar(13,28,-1.9+2*errdelta,"***")
errbar(22,25,-1.9+4*errdelta,"**")
errbar(25,28,-1.9,"***")

dev.off()
