#!/usr/bin/env Rscript

source("colors.R")

col <- c(control.col, rheb.col, pten.col, pten.rheb.col)

errdelta <- 0.12

errbar <- function(y, x0, x1, text="ns") {
	lines(x=c(x0, x1), y=c(y,y), col="gray", lwd=6)
	text(0.5*(x0+x1), y, text, cex=1.2)
}

clones <- read.table("../data/clones.txt", header=TRUE)

clones$logSize <- log(clones$Size)
clones$GenotypeC2 <- factor(ifelse(clones$GenotypeC=="WT", "WT", "Expr"))
clones$Manip <- interaction(clones$GenotypeL, clones$Sugar, clones$GenotypeC2)
clones$Manip <- droplevels(clones$Manip)

gen <- c("T3","RHEB","PTEN","PTEN-RHEB")
genlist <- lapply(gen, function(g) {
    wtref <- clones[clones$GenotypeL==g & clones$GenotypeC=="WT" & clones$Sugar=="0%","logSize"]
    genref <- clones[clones$GenotypeL==g & clones$GenotypeC!="WT"& clones$Sugar=="0%","logSize"]
    genref - mean(wtref) })
    
    
pdf("FigS2A.pdf", width=5, height=5)
par(lwd=2, mar=c(7, 4, 1, 1))
boxplot(genlist, horizontal=FALSE, xaxt="n", medcol="gray", range=0, ylim=c(-1.1, 2.8), boxwex=0.5, col=col, ylab="log area relative to Co:")
#~ mtext("log area relative to Co:", 1, adj=-0.8, line=1)
points(sapply(genlist, mean), pch=5)
axis(1, at=1:4, labels=c("Co", expression("Rheb"^"+"), expression("PTEN"^"-"), expression("PTEN"^"-"*";Rheb"^"+")), las=2)
abline(h=0, lty=3, col="darkgray") 

# P-values can be retrieved from TabS1 (part A)

errbar(2.5, 1, 2, "***")
errbar(2.5+errdelta, 1, 3, "***")
errbar(2.5+2*errdelta, 1, 4, "***")
errbar(-1, 2, 4, "***")
errbar(-1+errdelta, 3, 4, "***")

dev.off()
