#!/usr/bin/env Rscript

source("colors.R")

errbar <- function(x0, x1, y, text="ns") {
	lines(x=c(x0, x1), y=c(y,y), col="gray", lwd=6)
	text(0.5*(x0+x1), y, text, cex=1)
}
errdelta <- 0.16

clones <- read.table("../data/clonesB.txt", header=TRUE)

clones$logSize <- log(clones$Size)
clones$GenotypeC2 <- factor(ifelse(clones$GenotypeC=="WT", "WT", "Expr"))
clones$Manip <- interaction(clones$GenotypeL, clones$GenotypeC2)
clones$Manip <- droplevels(clones$Manip)

singlegen <- c("T3", "PTEN", "Rheb", "2L1", "2L1-PTEN", "2L1-Rheb", "DP", "DP-PTEN", "DP-Rheb", "2L19", "2L19-PTEN", "2L19-Rheb")

genlist <- lapply(singlegen, function(gen) {
    wtref <- clones[clones$GenotypeL==gen & clones$GenotypeC=="WT", "logSize"]
    genref <- clones[clones$GenotypeL==gen & clones$GenotypeC!="WT","logSize"]
    genref - mean(wtref) })

names(genlist) <- singlegen

xx <- c(1:3, 5:7, 9:11, 13:15)
col <- c(control.col, pten.col, rheb.col)

pdf("FigS2C.pdf", width=7, height=4.5)
par(lwd=2, mar=c(5, 4, 1, 1))


boxplot(genlist,  at=xx, xaxt="n", outline=FALSE, ylim=c(-4.1, 2), ylab="log area relative to Co", medcol="white", medlwd=3, col=col)
abline(h=0, col="gray", lty=3)
points(xx, sapply(genlist, mean), col="black", pch=5)
axis(1, at=xx, labels=rep(c("", expression("PTEN"^"-"),expression("Rheb"^"+")), 4), las=2, mgp=c(0, 0.7, 0)) 
axis(1, at=c(2,6,10,14), labels=c("T3","2L1",expression(Delta*P),"2L19"), tick=FALSE, mgp=c(0, 3.5, 0))

# P-values can be retrieved in TabS7

errbar(1, 2, -2, "***")
errbar(1, 3, -2-errdelta, "***")

errbar(1, 5, -2-3*errdelta, "***")
errbar(1, 6, -2-4*errdelta, "ns")
errbar(1, 7, -2-5*errdelta, "***")

errbar(1, 9, -2-7*errdelta, "***")
errbar(1, 10, -2-8*errdelta, "***")
errbar(1, 11, -2-9*errdelta, "***")

errbar(1, 13, -2-11*errdelta, "***")
errbar(1, 14, -2-12*errdelta, "***")
errbar(1, 15, -2-13*errdelta, "***")

# The y0 is adjusted by trial and error -- need to do it again if ylim is changed. 
arrows(x0=c(1, 5, 9, 13)-0.5, x1=c(3, 7, 11, 15)+0.5, y0=-5.75, angle=90, code=3, length=0., xpd=NA)

dev.off()
