#!/usr/bin/env Rscript

source("colors.R")

col <- c(control.col, fasn.col, darken(control.col, 1.2), darken(fasn.col, 1.2))
errdelta <- 0.05

errbar <- function(x0, x1, y, text="ns") {
	lines(x=c(x0, x1), y=c(y,y), col="gray", lwd=6)
	text(0.5*(x0+x1), y, text, cex=1.2)
}

pupsize <- read.table("../data/pupal-size2.txt", header=TRUE)

pupsize$Genotype <- relevel(pupsize$Genotype, "white")  # white are the control
pupsize$Sugar <- relevel(pupsize$Sugar, "0%")           # 0% are the control

#~ cylinder.volume <- function(length, width) pi*length*width*width/4
ellipsoid.volume <- function(length, width) pi*length*width*width/6

volume <- ellipsoid.volume
pupsize$Volume <- volume(pupsize$Length, pupsize$Width)

sss <- split(pupsize$Volume, list(pupsize$Genotype, pupsize$Sugar, pupsize$Sex))

errdelta <- 0.07

pdf("FigS3B.pdf", width=3.5, height=4)
par(mar=c(3.5, 3.5, 1, 1))
boxplot(sss, at=c(1:4, 6:9), xlim=c(0, 10), ylim=c(0, 1.9), main="", range=0, xaxt="n", col=col, medcol="gray", ylab="")
mtext(expression("Pupal volume (mm"^3*")"), 2, line=2.2)
points(c(1:4, 6:9), sapply(sss, mean), pch=5)
text(c(1:4, 6:9), y=sapply(sss, max), labels=as.character(sapply(sss, length)), pos=3, cex=0.7, col="darkgray")

axis(1, at=c(1.5, 3.5, 6.5, 8.5), labels=c("0%","10%", "0%", "10%"), line=0, mgp=c(1, 0.5, 1))
axis(1, at=c(2.5, 7.5), labels=c("Females","Males"), tick=FALSE, line=0.5)
mtext("Sucrose:", 1, adj=-0.2, line=0.5)

legend("topright", legend=c("             ", ""), pch=22, pt.bg=col[1:2], bty="n", pt.cex=1.5)
legend("topright", legend=c("Co","FASN"), pch=22, pt.bg=col[3:4], bty="n", pt.cex=1.5)

# P-values can be retrieved from TabS4

errbar(1, 3, 0.1, "*")
errbar(6, 8, 0.1, "ns")
errbar(2, 4, 0.1+errdelta, "ns")
errbar(7, 9, 0.1+errdelta, "ns")
errbar(1, 2, 0.1+2*errdelta, "***")
errbar(3, 4, 0.1+2*errdelta, "***")
errbar(6, 7, 0.1+2*errdelta, "***")
errbar(8, 9,  0.1+2*errdelta, "***")

dev.off()
