#!/usr/bin/env Rscript

library(xtable)
library(lme4)
library(multcomp)


ps6 <- read.table("../data/black-red.txt", header=TRUE)
ps6$PS6 <- ifelse(ps6$Color=="red", 1, 0)
ps6$Genotype <- relevel(ps6$Genotype, ref="MARCM-T3")

mod.ps6.3 <- glmer(PS6 ~ 0 + Genotype + (1|Larva/Series), data=ps6, family=binomial())

ps6.contrasts <- mcp(Genotype=c(
    'FASN- - Co'="`MARCM-FAS` - `MARCM-T3` = 0",
    'PTEN- - Co'="`MARCM-PTEN-512` - `MARCM-T3` = 0",
    'Rheb+ - Co'="`MARCM-T3-Rheb` - `MARCM-T3` = 0", 
    'TOR2L1 - Co'="`TOR2L1` - `MARCM-T3` = 0",
    'TORDeltaP - Co'="`TORDeltaP` - `MARCM-T3` = 0",
    'TOR2L19 - Co'="`TOR2L19` - `MARCM-T3` = 0")
    )
    
ps6.contgg <- summary(glht(mod.ps6.3, linfct=ps6.contrasts), test=adjusted("holm"))
xt.cont <- xtable(data.frame("Effect" = ps6.contgg$test$coefficients, 
                            "Std.Err." = ps6.contgg$test$sigma, 
                            "Adj.Pvalue"= ps6.contgg$test$pvalues,
                            row.names=names(ps6.contrasts$Genotype)), 
								digits=c(0, 3, 3, 4),
								caption="Statistical test of the difference in frequency between MARCM clones to control. The model is a mixed effect, generalized linear model considering frequencies as binomial data and genotype as a fixed effect, while larvae / series were random effects. P-values were adjusted for multiple testing by a Holm-Bonferroni correction.")

print(xt.cont, type="html", file="TabS2.html")
