#!/usr/bin/env Rscript

library(xtable)
library(lme4)
library(multcomp)

# This analysis corresponds to the data presented in Fig3

pupweight <- read.table("../data/pupal-weight.txt", header=TRUE)
# pupal weight in mg
pupweight$Mass <- c(0, diff(pupweight$CumulMass))/10
# The first line of each series is useless (the 0 measure on the scale)
pupweight <- pupweight[pupweight$Mass > 0,]
pupweight$Genotype <- relevel(pupweight$Genotype, "white")  # white are the control
pupweight$Sugar <- relevel(pupweight$Sugar, "0%")           # 0% are the control
pupweight$Forgotten <- relevel(pupweight$Forgotten, "OK")   

TAGProt <- read.table("../data/TAGProt.txt", header=TRUE)
Sugars <- read.table("../data/Sugars.txt", header=TRUE)

TAGProt$TAGmpup <- TAGProt$TAGM/TAGProt$PupWeight
TAGProt$Protmpup <- TAGProt$ProtM/TAGProt$PupWeight

Sugars$Threampup <- Sugars$ThreaM/Sugars$PupWeight
Sugars$Glycmpup <- Sugars$GlycM/Sugars$PupWeight


alllm <- function(data, phen,  factor.levels=c("W", "Ri37", "Rheb")) {
    newd <- data.frame(Genotype=data$Genotype, Sugar=data$Sugar, Phen=data[,phen])
    newd$Genotype <- factor(newd$Genotype, levels=factor.levels)
    newd$All <- interaction(newd$Genotype, newd$Sugar)
    
    mod <- lm(Phen ~ 0 + All, data=newd)
    gg <- glht(mod, linfct=mcp(All=c(
        paste0("`", factor.levels[2], ".0%` - `", factor.levels[1], ".0%` = 0"), 
        paste0("`", factor.levels[3], ".0%` - `", factor.levels[1], ".0%` = 0"), 
        paste0("`", factor.levels[2], ".20%` - `", factor.levels[1], ".20%` = 0"), 
        paste0("`", factor.levels[3], ".20%` - `", factor.levels[1], ".20%` = 0"))))
    smgg <- summary(gg, test=adjusted("holm"))
    data.frame("Effect" = smgg$test$coefficients, 
                "Std. Err." = smgg$test$sigma, 
                "Adj. Pvalue"   = smgg$test$pvalues,
					row.names=c("0%: PTEN - Co", "0%: Rheb - Co", "20%: PTEN - Co", "20%: Rheb - Co"))
}

print(xtable(alllm(pupweight[pupweight$Sex=="male",], "Mass", factor.levels=c("white", "PTEN","Rheb")), digits=c(0, 4, 4, 4), caption="Mass, Males"),type="html", file="TabS3.html", caption.placement="top")
print(xtable(alllm(pupweight[pupweight$Sex=="female",], "Mass", factor.levels=c("white", "PTEN","Rheb")), digits=c(0, 4, 4, 4), caption="Mass, Females"),type="html", file="TabS3.html", append=TRUE, caption.placement="top")
print(xtable(alllm(TAGProt, "Protmpup"), digits=c(0, 4, 4, 4), caption="Protein"),type="html", file="TabS3.html", append=TRUE, caption.placement="top")
print(xtable(alllm(TAGProt, "TAGmpup"), digits=c(0, 4, 4, 4), caption="TAG"),type="html", file="TabS3.html", append=TRUE, caption.placement="top")
print(xtable(alllm(Sugars, "Glycmpup"), digits=c(0, 4, 4, 4), caption="Glycogen"),type="html", file="TabS3.html", append=TRUE, caption.placement="top")
print(xtable(alllm(Sugars, "Threampup"), digits=c(0, 4, 4, 4), caption="Threalose"),type="html", file="TabS3.html", append=TRUE, caption.placement="top")
