#!/usr/bin/env Rscript

source("./compareContrasts.R")
source("./helperFigures.R")

library(xtable)



contrasts <- list(
    list(list(Sex="male", Genotype="white", Sugar="0%"), list(Sex="male", Genotype="white", Sugar="10%")),
    list(list(Sex="female", Genotype="white", Sugar="0%"), list(Sex="female", Genotype="white", Sugar="10%")),
    list(list(Sex="male", Genotype="FAS", Sugar="0%"), list(Sex="male", Genotype="FAS", Sugar="10%")),
    list(list(Sex="female", Genotype="FAS", Sugar="0%"), list(Sex="female", Genotype="FAS", Sugar="10%")),
    
    list(list(Sex="male", Genotype="white", Sugar="0%"), list(Sex="male", Genotype="FAS", Sugar="0%")),
    list(list(Sex="female", Genotype="white", Sugar="0%"), list(Sex="female", Genotype="FAS", Sugar="0%")),
    list(list(Sex="male", Genotype="white", Sugar="10%"), list(Sex="male", Genotype="FAS", Sugar="10%")),
    list(list(Sex="female", Genotype="white", Sugar="10%"), list(Sex="female", Genotype="FAS", Sugar="10%")))


############## First part: pupal weight (corresponding to Fig 6B)

pupweight2 <- read.table("../data/pupal-weight2.txt", header=TRUE)
# pupal weight in mg
pupweight2$Mass <- c(0, diff(pupweight2$CumulMass))/10
# The first line of each series is useless (the 0 measure on the scale)
pupweight2 <- pupweight2[pupweight2$Mass > 0,]
pupweight2$Genotype <- relevel(pupweight2$Genotype, "white")  # white are the control
pupweight2$Sugar <- relevel(pupweight2$Sugar, "0%")           # 0% are the control

ans <- compareContrasts(pupweight2, "Mass", contrasts)

ans$contrasts[,"Pr(>|t|)"] <- p.adjust(ans$contrasts[,"Pr(>|t|)"])
xt <- xtable(ans$contrasts, center="centering", floating=FALSE, digits=c(0, 3, 3, 3, 5), caption=
		"Prepupal weight differences (Estimate and standard error, in mg) between control and FASN genotypes in absence/presence of sucrose, in males and females. The last column indicate P-values corrected for multiple testing (Holm-Bonferoni correction)." )
rownames(xt) <- simpContrasts(rownames(xt))
print(xt, file="TabS4.html", hline.after=c(-1,0,4,8), type="html")


############# Second part: pupal volume (corresponding to Fig S3B)


pupsize <- read.table("../data/pupal-size2.txt", header=TRUE)

pupsize$Genotype <- relevel(pupsize$Genotype, "white")  # white are the control
pupsize$Sugar <- relevel(pupsize$Sugar, "0%")           # 0% are the control

#~ cylinder.volume <- function(length, width) pi*length*width*width/4
ellipsoid.volume <- function(length, width) pi*length*width*width/6

volume <- ellipsoid.volume
pupsize$Volume <- volume(pupsize$Length, pupsize$Width)

ans <- compareContrasts(pupsize, "Volume", contrasts)

ans$contrasts[,"Pr(>|t|)"] <- p.adjust(ans$contrasts[,"Pr(>|t|)"])
xt <- xtable(ans$contrasts, center="centering", floating=FALSE, digits=c(0, 3, 3, 3, 5), caption=
		"Prepupal volume differences (assuming an ellipsoid pupae, volume in mm2) between control and FASN genotypes in absence/presence of sucrose, in males and females. The last column indicate P-values corrected for multiple testing (Holm-Bonferoni correction)." )
rownames(xt) <- simpContrasts(rownames(xt))
print(xt, file="TabS4.html", hline.after=c(-1,0,4,8), type="html", append=TRUE)

