#!/usr/bin/env Rscript

library(xtable)
library(survival)


longevity <- read.table("../data/longevity.txt", header=TRUE, stringsAsFactors=TRUE)

long <- do.call(rbind, lapply(split(longevity, list(longevity$Replicate, longevity$Sex, longevity$Genotype)), function(dd) {
		remaining2 <- dd$Remaining
		remaining2[is.na(remaining2)] <- 0
		deaths <- abs(diff(remaining2))
		ans <- do.call(rbind, lapply(seq_along(deaths), function(i) if (is.na(deaths[i]) || deaths[i] == 0) NULL else data.frame(Sex=dd$Sex[1], Genotype=dd$Genotype[1], Replicate=dd$Replicate[1], begin=rep(dd$Time[i]-min(dd$Time), deaths[i]), end=rep(if (is.na(dd$Remaining[i+1])) NA else dd$Time[i+1]-min(dd$Time), deaths[i]))))
	}))
	
longMales <- long[long$Sex == "male",]
longFemales <- long[long$Sex == "female",]	
	
mySurv <- function(dd, algo="mean.interval") {
	if (algo == "mean.interval")
		Surv(ifelse(is.na(dd$end), dd$begin, 0.5*(dd$begin+dd$end)), event=ifelse(is.na(dd$end), 0, 1))
}


formatTable <- function(summ, caption="") {
	st <- summ$table[grepl(rownames(summ$table), pattern="Genotype"), c("Value", "Std. Err", "p")]
	rownames(st) <- paste0("Co -- ", sapply(strsplit(rownames(st), "Genotype"), "[", 2))
	xt <- xtable(st, center="centering", floating=FALSE, digits=c(0, 3, 3, 5), 
		caption=caption)
}

####### Model fitting

sMales <- survreg(mySurv(longMales) ~ Genotype + cluster(Replicate), data=longMales, dist="weibull")
sFemales <- survreg(mySurv(longFemales) ~ Genotype + cluster(Replicate), data=longFemales, dist="weibull")

print(formatTable(summary(sMales), caption="Survival analysis (Males)"), file="TabS5.html", hline.after=c(-1,0,4), type="html")
print(formatTable(summary(sFemales), caption="Survival analysis (Females)"), file="TabS5.html", append=TRUE, hline.after=c(-1,0,4), type="html")


###### For visual inspection

#~ col <- c(Co="blue", FASN="red", PK="darkgreen", PDH="violet", PFK="cyan", LDH="orange")
#~ ss <- seq(0.00001, 0.99999, length.out=101)

#~ pdf("TabS5-fig.pdf", width=5, height=10)
#~ layout((1:2))
#~ plot(survfit(mySurv(longMales) ~ longMales$Genotype), col=col[levels(longMales$Genotype)], main="Males")
#~ for (gg in names(col))
#~ 	lines(predict(sMales,newdata=data.frame(Genotype=gg, Replicate="R1"), type="quantile", p=ss),rev(ss), col=col[gg], lty=2) # Replicate does not matter
#~ legend("topright", lty=1, col=col, legend=names(col), bty="n")

#~ plot(survfit(mySurv(longFemales) ~ longFemales$Genotype), col=col[levels(longFemales$Genotype)], main="Females")
#~ for (gg in names(col))
#~ 	lines(predict(sFemales,newdata=data.frame(Genotype=gg, Replicate="R61"), type="quantile", p=ss),rev(ss), col=col[gg], lty=2) # Replicate does not matter
#~ 	dev.off()
