#!/usr/bin/env Rscript

library(multcomp)
library(lme4)

# This analysis corresponds to Fig S2C

clones <- read.table("../data/clonesB.txt", header=TRUE)

clones$logSize <- log(clones$Size)
clones$GenotypeC2 <- factor(ifelse(clones$GenotypeC=="WT", "WT", "Expr"))
clones$Manip <- interaction(clones$GenotypeL, clones$GenotypeC2)
clones$Manip <- droplevels(clones$Manip)



contrastline <- function(gen1, gen2="T3", lev=levels(clones$Manip)) {
    stopifnot(gen1 %in% levels(clones$GenotypeL), gen2 %in% levels(clones$GenotypeL))
    ll <- rep(0, length(lev))
    names(ll) <- lev
    ll[paste(gen1, "Expr", sep=".")] <- ll[paste(gen1, "Expr", sep=".")] + 1
    ll[paste(gen1, "WT", sep=".")] <- ll[paste(gen1, "WT", sep=".")] - 1
    ll[paste(gen2, "Expr", sep=".")] <- ll[paste(gen2, "Expr", sep=".")] - 1    
    ll[paste(gen2, "WT", sep=".")] <- ll[paste(gen2, "WT", sep=".")] + 1
    return(ll)
}

#~ cont8b <- rbind(
#~ 	'PTEN- - Co' = contrastline("PTEN", "T3"),
#~ 	'Rheb+ - Co'  = contrastline("Rheb", "T3"),
#~ 	'PTEN- - Rheb+' = contrastline("PTEN", "Rheb"),
#~ 	'2L1 - 2L1,PTEN-' = contrastline("2L1", "2L1-PTEN"),
#~ 	'2L1 - 2L1;Rheb+' = contrastline("2L1", "2L1-Rheb"),
#~ 	'2L1,PTEN- - 2L1;Rheb+' = contrastline("2L1-PTEN", "2L1-Rheb"),
#~ 	'DP - DP,PTEN-' = contrastline("DP","DP-PTEN"),
#~ 	'DP - DP;Rheb+' = contrastline("DP","DP-Rheb"),
#~ 	'DP,PTEN- - DP;Rheb+' = contrastline("DP-PTEN", "DP-Rheb"),
#~ 	'2L19 - 2L19,PTEN-' = contrastline("2L19", "2L19-PTEN"),
#~ 	'2L19 - 2L19;Rheb+' = contrastline("2L19", "2L19-Rheb"),
#~ 	'2L19,PTEN- - 2L19;Rheb+' = contrastline("2L19-PTEN", "2L19-Rheb")
#~ )

cont8 <- rbind(
	'PTEN- - Co'  = contrastline("PTEN", "T3"),
	'Rheb+ - Co'  = contrastline("Rheb", "T3"),
	'2L1 - Co'    = contrastline("2L1", "T3"),
	'2L1,PTEN- - Co'= contrastline("2L1-PTEN", "T3"),
	'2L1;Rheb+ - Co'= contrastline("2L1-Rheb", "T3"),
	'DP - Co'     = contrastline("DP", "T3"),
	'DP,PTEN- - Co'=contrastline("DP-PTEN", "T3"),
	'DP;Rheb+ - Co'= contrastline("DP-Rheb", "T3"),
	'2L19 - Co'     = contrastline("2L19", "T3"),
	'2L19,PTEN- - Co'=contrastline("2L19-PTEN", "T3"),
	'2L19;Rheb+ - Co'= contrastline("2L19-Rheb", "T3")
)


maketable <- function(mod, cont, ...) {
	require(xtable)
	G <- glht(mod, linfct=mcp(Manip=cont))
	sm <- summary(G, test=adjusted("holm"))
	smt <- data.frame(
		'Estimate' = sm$test$coefficients,
		'Std error'= sm$test$sigma,
		'Adj P-value' = sm$test$pvalue)
	rownames(smt) <- names(sm$test$coefficients)
	xtable(smt, digits=4, ...)
}

# Not enough series to include it in the model
mod2 <- lmer(logSize ~ Manip+(1|Larva), data=clones)

print(maketable(mod2, cont8, caption="Statistical tests corresponding to figure S2C. The model tests for the difference in the log ratio of GFP vs. unlabelled clones between pairs of genotypes (Co = control), accounting for larvae random effects (see the Methods section). P-values were corrected for multiple testing (Holm-Bonferroni method) and quantify the risk of rejecting the true null hypothesis at the table level."), type="html", file="TabS7.html")

