
simpContrasts <- function(cont) {
    sapply(cont, gsub, pattern='\\w+=', replacement='')
}

adddata <- function(x, at=1:length(x), pch=1, col=1, jitt=FALSE, pool=diff(range(unlist(x)))/20) {
    is.even <- function(x) x %% 2 == 0
    
    stopifnot(is.list(x))
    scale <- min(diff(at))
    stopifnot(length(at) == length(x))
    
    cut.breaks <- seq(min(unlist(x))-pool, max(unlist(x))+pool, by=pool)
    
    for(i in seq_along(at)) {
        real.x <- x[[i]] # a bit confusing, x is in fact y
        cut.x <- cut(x[[i]], breaks=cut.breaks)
        pos.x <- sapply(seq_along(cut.x), function(j) { if (j==1) return(0); sum(cut.x[1:(j-1)] == cut.x[j]) })
        new.at <-  at[i] + ifelse(is.even(pos.x), 1, -1)*ceiling(pos.x/2)*0.9*scale/max(pos.x)
        if(jitt) 
            new.at <- at[i] + runif(length(real.x), -0.9*scale/2, 0.9*scale/2) 
        points(new.at, real.x, pch=rep(pch, length.out=length(at))[i], col=rep(col, length.out=length(at))[i])
    }
}

addpvalues <- function(pv, nm = names(datasplit2), at, ylow=0.2, ysep=0.1, stars=TRUE, collabel = "Pr(>|t|)") {
    whichcontnum <- function(contr) {
        ss2 <- unlist(strsplit(contr, split=","))
        ss3 <- unlist(strsplit(ss2, split="="))
        which(nm==nm[grepl(nm, pattern=paste0("^", ss3[2], ".*\\.", ss3[4], ".*\\.", ss3[6]))])
    }
    whichcont <- function(contr) {
        sapply(strsplit(contr, split=" vs. ")[[1]], whichcontnum)
    }
    
    already.used <- NULL
    height.count <- 0
    for (i in seq_along(rownames(pv))) {
        cat <- unlist(whichcont(rownames(pv)[i]))
        if(length(cat) == 2) {
            if (length(already.used) == 0 || all(cat > max(already.used)) || all(cat < min(already.used))) {
                height.count <- 0
            } else {
                height.count <- height.count+1
            }
            already.used <- unique(c(already.used, cat))
            yy <- ylow+height.count*ysep
            arrows(x0=at[cat[1]], x1=at[cat[2]], y0=yy, code=3, angle=90, length=0.)
            txt <- ""
            if (stars) {
                if (pv[i,collabel] > 0.05) txt <- "NS"
                if (pv[i,collabel] <= 0.05) txt <- "*"
                if (pv[i,collabel] <= 0.01) txt <- "**"
                if (pv[i,collabel] <= 0.001) txt <- "***"
            } else {
                txt <- paste0("p=", round(pv[i,collabel], digits=4))
            }
            text(x=mean(c(at[cat[1]], at[cat[2]])), y=yy, pos=1, labels=txt)
        }
    }
}

myplot <- function(datasplit2, at = NULL, type=c("boxplot", "none"), add.data=FALSE, col=1, pch=1, xlim=range(at)+c(-1, 1), ylim=c(0, max(unlist(datasplit2))), ...) {

    if (is.null(at)) {
        sers <- length(datasplit2)
        at <- c(1:(sers/2), (sers/2+1):sers+1)
    }

    if (type[1] == "boxplot") {
        boxplot(datasplit2, at=at, col=rep(col, 2), xlim=xlim, ylim=ylim, ...)
    } else { # none of the allowed types or "none"
        plot(NULL, xlim=xlim, ylim=ylim, ...)
    }
    if (add.data) {
        adddata(datasplit2, at=at, col=rep(col, 2), pch=rep(pch, 2))
    }
}
